%bcond_without ocaml

Summary:        Read and write Windows Registry binary hive files
Name:           hivex
Version:        1.3.23
Release:        5%{?dist}

License:        LGPLv2
URL:            http://libguestfs.org/

Source0:        http://libguestfs.org/download/hivex/%{name}-%{version}.tar.gz

BuildRequires:  gcc make perl-interpreter perl-devel perl-generators
BuildRequires:  %{_bindir}/pod2html %{_bindir}/pod2man
BuildRequires:  perl(bytes) perl(Carp) perl(Encode) perl(ExtUtils::MakeMaker)
BuildRequires:  perl(Exporter) perl(IO::Scalar) perl(IO::Stringy) perl(strict)
BuildRequires:  perl(Test::More) perl(utf8) perl(vars) perl(warnings) perl(XSLoader)
BuildRequires:  perl(Test::Pod) >= 1.00 perl(Test::Pod::Coverage) >= 1.00
BuildRequires:  python3-devel ruby-devel rubygem-rake rubygem(json) rubygem(minitest)
BuildRequires:  rubygem(rdoc) readline-devel libxml2-devel
%if %{with ocaml}
BuildRequires:  ocaml
BuildRequires:  ocaml-findlib-devel
%endif

Requires:       %{name}-libs = %{version}-%{release}

Provides:      bundled(gnulib)


%description
Hive files are the undocumented binary files that Windows uses to
store the Windows Registry on disk.  Hivex is a library that can read
and write to these files.

'hivexsh' is a shell you can use to interactively navigate a hive
binary file.

'hivexregedit' (in perl-hivex) lets you export and merge to the
textual regedit format.

'hivexml' can be used to convert a hive file to a more useful XML
format.

In order to get access to the hive files themselves, you can copy them
from a Windows machine.  They are usually found in
%%systemroot%%\system32\config.  For virtual machines we recommend
using libguestfs or guestfish to copy out these files.  libguestfs
also provides a useful high-level tool called 'virt-win-reg' (based on
hivex technology) which can be used to query specific registry keys in
an existing Windows VM.
%if %{with ocaml}
For OCaml bindings, see 'ocaml-hivex-devel'.
%endif
For Perl bindings, see 'perl-hivex'.

For Python 3 bindings, see 'python3-hivex'.

For Ruby bindings, see 'ruby-hivex'.


%package libs
Summary:        Library for %{name}


%description libs
%{name}-libs contains the library for %{name}.


%package devel
Summary:        Development tools and libraries for %{name}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       pkgconfig


%description devel
%{name}-devel contains development tools and libraries
for %{name}.


%if %{with ocaml}
%package -n ocaml-%{name}
Summary:       OCaml bindings for %{name}
Requires:      %{name}-libs = %{version}-%{release}


%description -n ocaml-%{name}
ocaml-%{name} contains OCaml bindings for %{name}.

This is for toplevel and scripting access only.  To compile OCaml
programs which use %{name} you will also need ocaml-%{name}-devel.


%package -n ocaml-%{name}-devel
Summary:       OCaml bindings for %{name}
Requires:      ocaml-%{name} = %{version}-%{release}
Requires:      %{name}-devel = %{version}-%{release}


%description -n ocaml-%{name}-devel
ocaml-%{name}-devel contains development libraries
required to use the OCaml bindings for %{name}.
%endif


%package -n perl-%{name}
Summary:       Perl bindings for %{name}
Requires:      %{name}-libs = %{version}-%{release}
Requires:      perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))


%description -n perl-%{name}
perl-%{name} contains Perl bindings for %{name}.


%package -n python3-%{name}
Summary:       Python 3 bindings for %{name}
Requires:      %{name}-libs = %{version}-%{release}

%description -n python3-%{name}
python3-%{name} contains Python 3 bindings for %{name}.


%package -n ruby-%{name}
Summary:       Ruby bindings for %{name}
Requires:      %{name}-libs = %{version}-%{release}
Requires:      ruby(release)
Requires:      ruby
Provides:      ruby(hivex) = %{version}

%description -n ruby-%{name}
ruby-%{name} contains Ruby bindings for %{name}.


%prep
%autosetup -p1


%build
%configure \
    PYTHON=%{__python3} \
%if !%{with ocaml}
    --disable-ocaml \
%endif
    --disable-static \
    %{nil}
%make_build INSTALLDIRS=vendor


%install
%make_install INSTALLDIRS=vendor

rm %{buildroot}%{_libdir}/libhivex.la

find %{buildroot} -name perllocal.pod -delete
find %{buildroot} -name .packlist -delete
find %{buildroot} -name '*.bs' -delete

rm %{buildroot}%{python3_sitearch}/libhivexmod.la

%find_lang %{name}


%check
if ! make check -k; then
    for f in $( find -name test-suite.log | xargs grep -l ^FAIL: ); do
        echo
        echo "***" $f "***"
        cat $f
        echo
    done
    exit 1
fi

%files -f %{name}.lang
%license LICENSE
%doc README.md
%{_bindir}/hivexget
%{_bindir}/hivexml
%{_bindir}/hivexsh
%{_mandir}/man1/hivexget.1*
%{_mandir}/man1/hivexml.1*
%{_mandir}/man1/hivexsh.1*


%files libs
%license LICENSE
%doc README.md
%{_libdir}/libhivex.so.*


%files devel
%license LICENSE
%doc README.md
%{_libdir}/libhivex.so
%{_mandir}/man3/hivex.3*
%{_includedir}/hivex.h
%{_libdir}/pkgconfig/hivex.pc

%if %{with ocaml}
%files -n ocaml-%{name}
%doc README.md
%{_libdir}/ocaml/hivex
%{_libdir}/ocaml/stublibs/*.so
%{_libdir}/ocaml/stublibs/*.so.owner
%exclude %{_libdir}/ocaml/hivex/*.a
%exclude %{_libdir}/ocaml/hivex/*.cmxa
%exclude %{_libdir}/ocaml/hivex/*.cmx
%exclude %{_libdir}/ocaml/hivex/*.mli


%files -n ocaml-%{name}-devel
%{_libdir}/ocaml/hivex/*.a
%{_libdir}/ocaml/hivex/*.cmxa
%{_libdir}/ocaml/hivex/*.cmx
%{_libdir}/ocaml/hivex/*.mli
%endif


%files -n perl-%{name}
%{perl_vendorarch}/*
%{_mandir}/man3/Win::Hivex.3pm*
%{_mandir}/man3/Win::Hivex::Regedit.3pm*
%{_bindir}/hivexregedit
%{_mandir}/man1/hivexregedit.1*


%files -n python3-%{name}
%{python3_sitearch}/hivex/
%{python3_sitearch}/*.so


%files -n ruby-%{name}
%doc ruby/doc/site/*
%{ruby_vendorlibdir}/hivex.rb
%{ruby_vendorarchdir}/_hivex.so


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.23-5
- Rebuilt for loongarch release

* Fri Jun 21 2024 Rebuild Robot <rebot@opencloudos.org> - 1.3.23-4
- [Type] other
- [DESC] Rebuilt for ocaml

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.23-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.23-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 09 2023 cunshunxia <cunshunxia@tencent.com> - 1.3.23-1
- upgrade to 1.3.23

* Tue Aug 08 2023 cunshunxia <cunshunxia@tencent.com> - 1.3.21-5
- Rebuilt for ocaml-findlib 1.9.6

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.21-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.21-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 29 2023 cunshunxia <cunshunxia@tencent.com> - 1.3.21-2
- enable ocaml.

* Thu Mar 09 2023 cunshunxia <cunshunxia@tencent.com> - 1.3.21-1
- initial build
